@@ -2,6 +2,7 @@ from selenium import webdriver as __webdriver
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities as __DesiredCapabilities
 from selenium.webdriver.support.ui import Select as __select
 from selenium.common import exceptions as __exceptions
+from selenium.webdriver.chrome.options import Options as options
 from mftoolbox.constants import Header as __header
 
 """
@@ -38,40 +39,47 @@ __caps = __DesiredCapabilities().CHROME
 __caps["pageLoadStrategy"] = "eager"
 # noinspection SpellCheckingInspection
 __options = __webdriver.ChromeOptions()
+
 __chrome_preferences = {'profile.managed_default_content_settings.images': 2}
-__ options.add_argument("headless")
+#__options.add_argument("headless")
 # noinspection SpellCheckingInspection
 __options.add_experimental_option("prefs", __chrome_preferences)
+__options.add_argument("disable-infobars")
 browser = __webdriver.Chrome(options=__options, service_args=['--silent'], desired_capabilities=__caps)
 browser.header_overrides = __header
+browser.set_window_position(10000,10000)
 # opening cleadr browse data page
 browser.get('chrome://settings/clearBrowserData')
 # find time range dropdown. Full xpath:
 # /html/body/# settings-ui//div[2]/settings-main//settings-basic-page//div[1]/settings-section[4]/settings-privacy-page
 # //# settings-clear-browsing-data-dialog//cr-dialog[1]/div[3]/iron-pages/div[2]/div/settings-dropdown-menu//select'
-__root1 = browser.find_element_by_tag_name("settings-ui")
-__shadow_root1 = __expand_shadow_element(browser, __root1)
-__root2 = __shadow_root1.find_element_by_css_selector("settings-main#main")
-__shadow_root2 = __expand_shadow_element(browser, __root2)
-__root3 = __shadow_root2.find_element_by_css_selector("settings-basic-page[role='main']")
-__shadow_root3 = __expand_shadow_element(browser, __root3)
-__webelement1 = __shadow_root3.find_element_by_css_selector("settings-section[page-title='Privacy and security']")
-__root4 = __webelement1.find_element_by_css_selector('settings-privacy-page')
-__shadow_root4 = __expand_shadow_element(browser, __root4)
-__root5 = __shadow_root4.find_element_by_css_selector('settings-clear-browsing-data-dialog')
-__shadow_root5 = __expand_shadow_element(browser, __root5)
-__root6 = __shadow_root5.find_element_by_id('clearBrowsingDataDialog')
-__webelement2 = __root6.find_element_by_id('clearFromBasic')
-__shadow_root6 = __expand_shadow_element(browser, __webelement2)
-__dropdown = __select(__shadow_root6.find_element_by_id('dropdownMenu'))
-#select option all time
-__dropdown.select_by_visible_text('All time')
-#find Clear Data Button and click
-__button = __root6.find_element_by_id('clearBrowsingDataConfirm')
-__button.click()
-# wait until button disapears
 try:
-    while __button.is_displayed():
+    __root1 = browser.find_element_by_tag_name("settings-ui")
+    __shadow_root1 = __expand_shadow_element(browser, __root1)
+    __root2 = __shadow_root1.find_element_by_css_selector("settings-main#main")
+    __shadow_root2 = __expand_shadow_element(browser, __root2)
+    __root3 = __shadow_root2.find_element_by_css_selector("settings-basic-page[role='main']")
+    __shadow_root3 = __expand_shadow_element(browser, __root3)
+    __webelement1 = __shadow_root3.find_element_by_css_selector("settings-section[page-title='Privacy and security']")
+    __root4 = __webelement1.find_element_by_css_selector('settings-privacy-page')
+    __shadow_root4 = __expand_shadow_element(browser, __root4)
+    __root5 = __shadow_root4.find_element_by_css_selector('settings-clear-browsing-data-dialog')
+    __shadow_root5 = __expand_shadow_element(browser, __root5)
+    __root6 = __shadow_root5.find_element_by_id('clearBrowsingDataDialog')
+    __webelement2 = __root6.find_element_by_id('clearFromBasic')
+    __shadow_root6 = __expand_shadow_element(browser, __webelement2)
+    __dropdown = __select(__shadow_root6.find_element_by_id('dropdownMenu'))
+    #select option all time
+    __dropdown.select_by_visible_text('All time')
+    #find Clear Data Button and click
+    __button = __root6.find_element_by_id('clearBrowsingDataConfirm')
+    __button.click()
+    # wait until button disapears
+    try:
+        while __button.is_displayed():
+            pass
+    except __exceptions.StaleElementReferenceException:
         pass
-except __exceptions.StaleElementReferenceException:
-    pass
+    #browser.set_window_position(browser_window_position['x'], browser_window_position['y'])
+except:
+    print('Não foi possível criar a instance dp browser')
\ No newline at end of file
